Components
--------------------------------------------------

Asent contains a bunch of components to get a full list you can always run:

.. code:: python

   import asent
   for c in asent.components.get_all():
      print(c)


.. code:: text

   asent_da_v1
   asent_en_v1
   asent_no_v1
   asent_sv_v1


asent.component
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: asent.component
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: create_asent_component